#!/usr/bin/python3 -Es
# -*- coding: utf-8 -*-
#
# Copyright (C) 2002-2018 Red Hat, Inc.
#
# Authors:
# Than Ngo <than@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import sys
import signal
import os.path
from backend import *
from snack import *

#
# I18N
#
gettext.textdomain(PROGNAME)
_ = gettext.gettext


class mainDialog:
    def __init__(self):
        mta_list = get_mta()

        if len(mta_list) == 0:
            self.warningDialog()
            sys.exit(1)
            
        screen = SnackScreen()
        t = TextboxReflowed(45, TEXT)
        li = Listbox(5, width = 20, returnExit = 1)

        # add mta into listbox
        for mta in mta_list:
            if mta == MTA[SENDMAIL]:
                li.append(MTA[SENDMAIL], SENDMAIL)
            if mta == MTA[POSTFIX]:
                li.append(MTA[POSTFIX], POSTFIX)
            if mta == MTA[EXIM]:
                li.append(MTA[EXIM], EXIM)
            if mta == MTA[SSMTP]:
                li.append(MTA[SSMTP], SSMTP)
            if mta == MTA[ESMTP]:
                li.append(MTA[ESMTP], ESMTP)

        # activate default mta
        mta = get_default_mta(mta_list)
        if mta == MTA[SENDMAIL]:
            li.setCurrent(SENDMAIL)
        elif mta == MTA[POSTFIX]:
            li.setCurrent(POSTFIX)
        elif mta == MTA[EXIM]:
            li.setCurrent(EXIM)
        elif mta == MTA[SSMTP]:
            li.setCurrent(SSMTP)
        elif mta == MTA[ESMTP]:
            li.setCurrent(ESMTP)

        # create button bar    
        bb = ButtonBar(screen, ((_('Ok'), 'ok'), (_('Cancel'), 'cancel')))

        g = GridForm(screen, TITLE, 1, 4)
        g.add(t, 0, 1)
        g.add(li, 0, 2, (0, 1, 0, 1))
        g.add(bb, 0, 3, growx = 1)

        result = g.runOnce()
        screen.finish()

        if bb.buttonPressed(result) != 'cancel':
            switch(li.current())
            self.infoDialog()

    def warningDialog(self):
        screen = SnackScreen()
        b =  Button(_('Ok'))
        t = TextboxReflowed(40, WARNING_TEXT+'\n\n')
        g = GridFormHelp(screen, _('Warning'), None, 1, 2)
        g.add(t, 0, 0)
        g.add(b, 0, 1)
    
        result = g.runOnce()
        screen.finish()

    def infoDialog(self):
        screen = SnackScreen()
        b =  Button(_('OK'))
        t = TextboxReflowed(45, INFO_TEXT + '\n\n')
        g = GridFormHelp(screen, _('Information'), None, 1, 2)
        g.add(t, 0, 0)
        g.add(b, 0, 1)
    
        result = g.runOnce()
        screen.finish()


# MAIN
app = mainDialog()
sys.exit(0)
